@@ -6,6 +6,7 @@ import sys
 import yaml
 import git
 import xxhash
+from dataclasses import dataclass
 from typing import Optional, Dict
 from metricflow.cli.main import _print_issues
 from metricflow.model.parsing.config_linter import ConfigLinter
@@ -25,9 +26,83 @@ LOCAL_DIR_DEFAULT = "."
 # TODO: Return error response so this constant doesn't have to be passed to the CLI
 ERROR_RESPONSE_PREFIX = "Error response: "
 
+
+@dataclass
+class RequiredModelDetails:
+    """Class Object for Required model details, pulled from the source control provider"""
+
+    # Set as "Optional" to work with linter, as it is not guaranteed that ther environment variables exist
+    REPO: Optional[str]
+    BRANCH: Optional[str]
+    COMMIT: Optional[str]
+
+
 logger = logging.getLogger(__name__)
 
 
+def parse_github() -> RequiredModelDetails:
+    """Pull environment variables from Github"""
+    REPO: Optional[str]
+    if os.getenv("REPO"):
+        REPO = os.getenv("REPO")
+    else:
+        REPO = os.getenv("GITHUB_REPOSITORY")
+
+    # Remove Github org from repo
+    if REPO:
+        REPO = "/".join(REPO.split("/")[1:])
+
+    BRANCH: Optional[str]
+    if os.getenv("GITHUB_HEAD_REF") == "":
+        github_ref = os.getenv("GITHUB_REF")
+        if github_ref:
+            BRANCH = github_ref.lstrip("/refs/heads/")
+    else:
+        BRANCH = os.getenv("GITHUB_HEAD_REF")
+
+    COMMIT = os.getenv("GITHUB_SHA")
+
+    return RequiredModelDetails(REPO=REPO, BRANCH=BRANCH, COMMIT=COMMIT)
+
+
+def parse_gitlab() -> RequiredModelDetails:
+    """Pull environment variables from Gitlab"""
+    REPO: Optional[str]
+    if os.getenv("REPO"):
+        REPO = os.getenv("REPO")
+    else:
+        REPO = os.getenv("CI_PROJECT_PATH")
+
+    # Remove Gitlab org from repo
+    if REPO:
+        REPO = "/".join(REPO.split("/")[1:])
+
+    BRANCH = os.getenv("CI_COMMIT_BRANCH")
+
+    COMMIT = os.getenv("CI_COMMIT_SHA")
+
+    return RequiredModelDetails(REPO=REPO, BRANCH=BRANCH, COMMIT=COMMIT)
+
+
+def parse_bitbucket() -> RequiredModelDetails:
+    """Pull environment variables from Bitbucket"""
+    REPO: Optional[str]
+    if os.getenv("REPO"):
+        REPO = os.getenv("REPO")
+    else:
+        REPO = os.getenv("BITBUCKET_REPO_FULL_NAME")
+
+    # Remove Gitlab org from repo
+    if REPO:
+        REPO = "/".join(REPO.split("/")[1:])
+
+    BRANCH = os.getenv("BITBUCKET_BRANCH")
+
+    COMMIT = os.getenv("BITBUCKET_COMMIT")
+
+    return RequiredModelDetails(REPO=REPO, BRANCH=BRANCH, COMMIT=COMMIT)
+
+
 def _err_msg_from_err_response(r: requests.Response) -> str:
     # Typically I'm against exceptions for control flow, but meh it's readable
     # in this case
@@ -42,19 +117,18 @@ def _err_msg_from_err_response(r: requests.Response) -> str:
 
 def read_config_files(config_dir: str) -> Dict:  # noqa: D
     try:
-        repo = git.Repo(".", search_parent_directories=True)
-        git_dir = repo.working_tree_dir
+        repo = git.Repo(config_dir, search_parent_directories=True)
     except git.exc.InvalidGitRepositoryError:
-        git_dir = None
+        repo = None
 
-    return _read_config_files(config_dir, git_dir)
+    return _read_config_files(config_dir, repo)
 
 
-def _read_config_files(config_dir: str, git_dir: Optional[str]) -> Dict:
+def _read_config_files(config_dir: str, git_repo: Optional[git.Repo]) -> Dict:
     """Read yaml files from config_dir. Returns (file name, file contents) per file in dir"""
     assert os.path.exists(config_dir), f"User-specified config dir ({config_dir}) does not exist"
 
-    results = {}
+    relative_file_paths = []
     for path, _folders, filenames in os.walk(config_dir):
         # This ensures we skip files in the dir's .git
         # For reference we ran into an issue wherein a remote branch
@@ -65,6 +139,7 @@ def _read_config_files(config_dir: str, git_dir: Optional[str]) -> Dict:
             continue
 
         for fname in filenames:
+            # ignore files that don't have a valid yaml extension
             if not (fname.endswith(".yml") or fname.endswith(".yaml")):
                 continue
 
@@ -72,17 +147,27 @@ def _read_config_files(config_dir: str, git_dir: Optional[str]) -> Dict:
             if fname in EXPECTED_TF_CONFIG_FILE_NAMES:
                 continue
 
-            with open(os.path.join(path, fname), "r") as f:
-                filepath = os.path.abspath(os.path.join(path, fname))
-                if git_dir is not None:
-                    filepath = filepath.split(git_dir)[-1]
-                results[filepath] = f.read()
-                try:
-                    yaml.safe_load_all(results[filepath])
-                except yaml.parser.ParserError as e:
-                    raise yaml.parser.ParserError(f"Invalid yaml in config file at path: {filepath}. {e}")
-                except Exception as e:
-                    raise Exception(f"Failed loading yaml config file. {e}")
+            relative_file_paths.append(os.path.join(path, fname))
+
+    # remove any .gitignore'd files
+    if git_repo:
+        ignored_files = git_repo.ignored(relative_file_paths)
+        relative_file_paths = list(set(relative_file_paths) - set(ignored_files))
+
+    results = {}
+    repo_dir = git_repo.working_tree_dir if git_repo else None
+    for relative_file_path in relative_file_paths:
+        with open(relative_file_path, "r") as f:
+            filepath = os.path.abspath(relative_file_path)
+            if repo_dir is not None:
+                filepath = filepath.split(repo_dir)[-1]
+            results[filepath] = f.read()
+            try:
+                yaml.safe_load_all(results[filepath])
+            except yaml.parser.ParserError as e:
+                raise yaml.parser.ParserError(f"Invalid yaml in config file at path: {filepath}. {e}")
+            except Exception as e:
+                raise Exception(f"Failed loading yaml config file. {e}")
 
     return results
 
@@ -231,7 +316,7 @@ def commit_configs_as_primary(
     # the only case where the resp wont have an "issues" key is if
     # return_issues == False AND there are blocking issues during validation
     # because in that case, the backend returns and http error response
-    if hasattr(json_resp, "issues"):
+    if "issues" in json_resp:
         results = ModelValidationResults.parse_raw(json_resp["issues"])
 
         # only promote the model if there aren't blocking issues
@@ -298,34 +383,19 @@ if __name__ == "__main__":
     if mode != UPLOAD_MODE_VALIDATE and mode != UPLOAD_MODE_COMMIT:
         raise ValueError(f"Invalid upload mode ({mode}) passed via args.")
 
-    # Retrieve git info and API key from env
-    REPO = os.getenv("REPO")
-
-    # Check for BitBucket Repo
-    if not REPO:
-        REPO = os.getenv("BITBUCKET_REPO_FULL_NAME")
-
-    # Remove Github/BitBucket org from repo
-    if REPO:
-        REPO = "/".join(REPO.split("/")[1:])
-
-    BRANCH: Optional[str]
-    if os.getenv("GITHUB_HEAD_REF") == "":
-        github_ref = os.getenv("GITHUB_REF")
-        if github_ref:
-            BRANCH = github_ref.lstrip("/refs/heads/")
-    elif os.getenv("BITBUCKET_BRANCH"):
-        # Check in case of BitBucket Branch
-        BRANCH = os.getenv("BITBUCKET_BRANCH")
+    model_details: RequiredModelDetails
+    if os.getenv("SOURCE_CONTROL") == "GITLAB":
+        model_details = parse_gitlab()
+    elif os.getenv("SOURCE_CONTROL") == "BITBUCKET":
+        model_details = parse_bitbucket()
+    elif os.getenv("SOURCE_CONTROL") == "GITHUB":
+        model_details = parse_github()
     else:
-        BRANCH = os.getenv("GITHUB_HEAD_REF")
+        # default: use Github
+        model_details = parse_github()
 
     API_URL = os.getenv("TRANSFORM_API_URL", TRANSFORM_API_URL)
 
-    COMMIT = os.getenv("GITHUB_SHA")
-    if not COMMIT:
-        COMMIT = os.getenv("BITBUCKET_COMMIT")
-
     TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR")
     if TRANSFORM_CONFIG_DIR:
         TRANSFORM_CONFIG_DIR = TRANSFORM_CONFIG_DIR.lstrip().rstrip()
@@ -335,9 +405,9 @@ if __name__ == "__main__":
     # This protects againsts the case where the varaible is None, making it "None"
     # In practice we've only seen this in our own org, and way back in March of 2021,
     # but I'd rather be safe than sorry
-    REPO = f"{REPO}"
-    BRANCH = f"{BRANCH}"
-    COMMIT = f"{COMMIT}"
+    REPO = f"{model_details.REPO}"
+    BRANCH = f"{model_details.BRANCH}"
+    COMMIT = f"{model_details.COMMIT}"
 
     lint_results = ConfigLinter().lint_dir(TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT)
     if lint_results.has_blocking_issues:
